@@ -73,6 +73,9 @@ options:
     data:
         description:
             - Keys and values to write.
+    alternate_data:
+        description:
+            - Keys and values to write. Use this if you need the returned data.
     update:
         description:
             - Update rather than overwrite.
@@ -96,7 +99,8 @@ def main():
     argspec['mount_point'] = dict(required=False, type='str', default='secret')
     argspec['secret'] = dict(required=True, type='str')
     argspec['update'] = dict(required=False, default=False, type='bool')
-    argspec['data'] = dict(required=False, default={}, type='dict')
+    argspec['data'] = dict(required=False, default={}, type='dict', no_log=True)
+    argspec['alternate_data'] = dict(required=False, default={}, type='dict')
     module = hashivault_init(argspec, supports_check_mode=True)
     result = hashivault_write(module)
     if result.get('failed'):
@@ -152,6 +156,7 @@ def hashivault_write(module):
     mount_point = params.get('mount_point')
     secret = params.get('secret')
     data = params.get('data')
+    data = data or params.get('alternate_data')
 
     if secret.startswith('/'):
         secret = secret.lstrip('/')
@@ -205,9 +210,11 @@ def hashivault_write(module):
                     else:
                         returned_data = client.write(secret_path, **write_data)
                     if returned_data:
-                        result['data'] = returned_data
-                        if returned_data is None:
-                            result['data'] = ''
+                        from requests.models import Response
+                        if isinstance(returned_data, Response):
+                            result['data'] = returned_data.text
+                        else:
+                            result['data'] = returned_data
                 except Exception as e:
                     result['rc'] = 1
                     result['failed'] = True
